==> kdepim-3.1.tar.bz2: kdepim-3.1/kpilot/conduits/abbrowserconduit/abbrowser-setup.h <==
#ifndef _ABBROWSER_ABBROWSER_SETUP_H
#define _ABBROWSER_ABBROWSER_SETUP_H
/* knotes-setup.h                       KPilot
**
** Copyright (C) 2001 by Dan Pilone
**
** This file defines the widget and behavior for the config dialog
** of the KNotes conduit.
*/
 
/*
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program in a file called COPYING; if not, write to
** the Free Software Foundation, Inc., 675 Mass Ave, Cambridge,
** MA 02139, USA.
*/
 
/*
** Bug reports and questions can be sent to kde-pim@kde.org
*/

#include "plugin.h"

class AbbrowserWidget;

class AbbrowserWidgetSetup : public ConduitConfig
{
Q_OBJECT
public:
	AbbrowserWidgetSetup(QWidget *,const char *,const QStringList &);
	virtual ~AbbrowserWidgetSetup();

	virtual void readSettings();

protected:
	virtual void commitChanges();

private:
	AbbrowserWidget *fConfigWidget;
} ;

// $Log: abbrowser-setup.h,v $
// Revision 1.1  2001/10/31 23:54:45  adridg
// CVS_SILENT: Ongoing conduits ports
//

#endif

==> kdepim-4.1.2.tar.bz2: kdepim-4.1.2/kpilot/conduits/abbrowserconduit/abbrowser-setup.h <==
#ifndef _ABBROWSER_ABBROWSER_SETUP_H
#define _ABBROWSER_ABBROWSER_SETUP_H
/* knotes-setup.h                       KPilot
**
** Copyright (C) 2001 by Dan Pilone
** Copyright (C) 2002-2003 Reinhold Kainhofer
**
** This file defines the widget and behavior for the config dialog
** of the KNotes conduit.
*/

/*
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program in a file called COPYING; if not, write to
** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
** MA 02110-1301, USA.
*/

/*
** Bug reports and questions can be sent to kde-pim@kde.org
*/

#include "plugin.h"

class AbbrowserWidget;
class KAboutData;

class AbbrowserWidgetSetup : public ConduitConfigBase
{
Q_OBJECT
public:
	AbbrowserWidgetSetup(QWidget *, const QVariantList &);
	virtual ~AbbrowserWidgetSetup();
	virtual void load();
	virtual void commit();
	static ConduitConfigBase *create(QWidget *);
private:
	AbbrowserWidget *fConfigWidget;
	KAboutData *fAbout;
} ;

#endif
